@@ -1,11 +1,14 @@
 """Constants for eboekhouden_python."""
-from .btw_code import BtwCode
+from .btw_code import BtwCode, btw_codes_hoog, btw_codes_laag, btw_codes_geen
 from .in_ex_btw import InExBTW
 from .mutatie_soort import MutatieSoort
 
 
 __all__ = [
     BtwCode,
+    btw_codes_hoog,
+    btw_codes_laag,
+    btw_codes_geen,
     InExBTW,
     MutatieSoort,
 ]
